@@ -6,7 +6,7 @@ use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -53,11 +53,16 @@ sub register_prereqs
 
     my $ab_version = '0.32';
 
-    foreach my $hook (qw( build_ffi gather_ffi patch_ffi ))
+    foreach my $hook (qw( build_ffi gather_ffi ))
     {
       $ab_version = '0.38';
     }
 
+    foreach my $hook (qw( patch_ffi ))
+    {
+      $ab_version = '0.39';
+    }
+
     if($self->_installer eq 'Makefile.PL')
     {
       $self->zilla->register_prereqs(
@@ -177,7 +182,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
